==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/people/classes/UseCase/GetRoleUsers.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_f4532747e" . "1604b7bf86" . "d299f9b9b0" . "583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBl" . "cm1pc3Npb24gdG8gdmlldyB0" . "aGlzIHJvbGU="), "_94c782c8180766e1ff1870" . "975a93053d" => base64_decode("Um9sZ" . "SBub3" . "QgZm9" . "1bmQ="));
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\UserFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;
class GetRoleUsers
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $role_repository;
    
    
    
    
    protected $get_users;
    
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_90f6cb30a269a622b4c838bfd5a0a5db, GetUsers $get_users)
    {
        $this->acl = $acl;
        $this->role_repository = $_90f6cb30a269a622b4c838bfd5a0a5db;
        $this->get_users = $get_users;
    }
    
    
    
    
    
    
    
    
    
    public function GetRoleUsers(SecurityContext $context, int $role_id, UserFilter $_03e9164d0a343b742df4793268b80767) : array
    {
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->role_repository->find($role_id);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_94c782c8180766e1ff1870975a93053" . "d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f4532747e1604b7bf86d2" . "99f9b9b0583"]);
        }
        $_03e9164d0a343b742df4793268b80767->SetPeopleAcl($this->acl);
        $_03e9164d0a343b742df4793268b80767->SetRoleIds($role_id);
        return $this->get_users->GetUsers($_03e9164d0a343b742df4793268b80767);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/people/classes/UseCase/GetRoleUsers.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_f4532747e1604b7bf86d" . "299f9b9b0583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc3Npb24gdG8gdmlldyB0aGlzIHJ" . "vbGU="), "_94c782c8180766e" . "1ff1870975a93053" . "d" => base64_decode("Um9sZSBub3Q" . "gZm91bmQ="));
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\UserFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;
class GetRoleUsers
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $role_repository;
    
    
    
    
    protected $get_users;
    
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_90f6cb30a269a622b4c838bfd5a0a5db, GetUsers $get_users)
    {
        $this->acl = $acl;
        $this->role_repository = $_90f6cb30a269a622b4c838bfd5a0a5db;
        $this->get_users = $get_users;
    }
    
    
    
    
    
    
    
    
    
    public function GetRoleUsers(SecurityContext $context, int $role_id, UserFilter $_03e9164d0a343b742df4793268b80767) : array
    {
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->role_repository->find($role_id);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_94c782c818" . "0766e1ff187" . "0975a93053d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_f4532747e1604" . "b7bf86d299f9b9" . "b0583"]);
        }
        $_03e9164d0a343b742df4793268b80767->SetPeopleAcl($this->acl);
        $_03e9164d0a343b742df4793268b80767->SetRoleIds($role_id);
        return $this->get_users->GetUsers($_03e9164d0a343b742df4793268b80767);
    }
}
